@@ -44,12 +44,13 @@ import java.util.StringTokenizer;
 import static org.apache.commons.io.IOUtils.closeQuietly;
 import static org.apache.maven.plugin.surefire.report.DefaultReporterFactory.TestResultType;
 import static org.apache.maven.plugin.surefire.report.FileReporterUtils.stripIllegalFilenameChars;
+import static org.apache.maven.plugin.surefire.report.ReportEntryType.SUCCESS;
 import static org.apache.maven.surefire.util.internal.StringUtils.UTF_8;
 import static org.apache.maven.surefire.util.internal.StringUtils.isBlank;
 
 @SuppressWarnings( { "javadoc", "checkstyle:javadoctype" } )
 // CHECKSTYLE_OFF: LineLength
-/**
+/*
  * XML format reporter writing to <code>TEST-<i>reportName</i>[-<i>suffix</i>].xml</code> file like written and read
  * by Ant's <a href="http://ant.apache.org/manual/Tasks/junit.html"><code>&lt;junit&gt;</code></a> and
  * <a href="http://ant.apache.org/manual/Tasks/junitreport.html"><code>&lt;junitreport&gt;</code></a> tasks,
@@ -81,6 +82,7 @@ import static org.apache.maven.surefire.util.internal.StringUtils.isBlank;
  * @see <a href="http://wiki.apache.org/ant/Proposals/EnhancedTestReports">Ant's format enhancement proposal</a>
  *      (not yet implemented by Ant 1.8.2)
  */
+@Deprecated // this is no more stateless due to existence of testClassMethodRunHistoryMap since of 2.19. Rename to StatefulXmlReporter in 3.0.
 public class StatelessXmlReporter
 {
     private final File reportsDirectory;
@@ -146,13 +148,12 @@ public class StatelessXmlReporter
                 {
                     if ( rerunFailingTestsCount > 0 )
                     {
-                        TestResultType resultType = getTestResultType( methodEntryList );
-                        switch ( resultType )
+                        switch ( getTestResultType( methodEntryList ) )
                         {
                             case success:
                                 for ( WrappedReportEntry methodEntry : methodEntryList )
                                 {
-                                    if ( methodEntry.getReportEntryType() == ReportEntryType.SUCCESS )
+                                    if ( methodEntry.getReportEntryType() == SUCCESS )
                                     {
                                         startTestElement( ppw, methodEntry, reportNameSuffix,
                                                           methodEntryList.get( 0 ).elapsedTimeAsString() );
@@ -188,7 +189,7 @@ public class StatelessXmlReporter
                                 // Get the run time of the first successful run
                                 for ( WrappedReportEntry singleRunEntry : methodEntryList )
                                 {
-                                    if ( singleRunEntry.getReportEntryType() == ReportEntryType.SUCCESS )
+                                    if ( singleRunEntry.getReportEntryType() == SUCCESS )
                                     {
                                         runtime = singleRunEntry.elapsedTimeAsString();
                                         break;
@@ -197,7 +198,7 @@ public class StatelessXmlReporter
                                 startTestElement( ppw, methodEntryList.get( 0 ), reportNameSuffix, runtime );
                                 for ( WrappedReportEntry singleRunEntry : methodEntryList )
                                 {
-                                    if ( singleRunEntry.getReportEntryType() != ReportEntryType.SUCCESS )
+                                    if ( singleRunEntry.getReportEntryType() != SUCCESS )
                                     {
                                         getTestProblems( fw, ppw, singleRunEntry, trimStackTrace, outputStream,
                                                          singleRunEntry.getReportEntryType().getFlakyXmlTag(), true );
@@ -224,7 +225,7 @@ public class StatelessXmlReporter
                         for ( WrappedReportEntry methodEntry : methodEntryList )
                         {
                             startTestElement( ppw, methodEntry, reportNameSuffix, methodEntry.elapsedTimeAsString() );
-                            if ( methodEntry.getReportEntryType() != ReportEntryType.SUCCESS )
+                            if ( methodEntry.getReportEntryType() != SUCCESS )
                             {
                                 getTestProblems( fw, ppw, methodEntry, trimStackTrace, outputStream,
                                                  methodEntry.getReportEntryType().getXmlTag(), false );
@@ -403,9 +404,21 @@ public class StatelessXmlReporter
             }
         }
 
+        boolean hasNestedElements = createOutErrElementsInside & stackTrace != null;
+
         if ( stackTrace != null )
         {
+            if ( hasNestedElements )
+            {
+                ppw.startElement( "stackTrace" );
+            }
+
             ppw.writeText( extraEscape( stackTrace, false ) );
+
+            if ( hasNestedElements )
+            {
+                ppw.endElement();
+            }
         }
 
         if ( createOutErrElementsInside )
@@ -502,12 +515,12 @@ public class StatelessXmlReporter
 
         private int c2;
 
-        public EncodingOutputStream( OutputStream out )
+        EncodingOutputStream( OutputStream out )
         {
             super( out );
         }
 
-        public OutputStream getUnderlying()
+        OutputStream getUnderlying()
         {
             return out;
         }
