@@ -86,7 +86,7 @@ public final class ForkedBooter
 
     private void setupBooter( String tmpDir, String dumpFileName, String surefirePropsFileName,
                               String effectiveSystemPropertiesFileName )
-            throws IOException, SurefireExecutionException
+            throws IOException
     {
         BooterDeserializer booterDeserializer =
                 new BooterDeserializer( createSurefirePropertiesIfFileExists( tmpDir, surefirePropsFileName ) );
@@ -95,7 +95,8 @@ public final class ForkedBooter
         setSystemProperties( new File( tmpDir, effectiveSystemPropertiesFileName ) );
 
         providerConfiguration = booterDeserializer.deserialize();
-        DumpErrorSingleton.getSingleton().init( dumpFileName, providerConfiguration.getReporterConfiguration() );
+        DumpErrorSingleton.getSingleton()
+                .init( providerConfiguration.getReporterConfiguration().getReportsDirectory(), dumpFileName );
 
         startupConfiguration = booterDeserializer.getProviderConfiguration();
         systemExitTimeoutInSeconds = providerConfiguration.systemExitTimeout( DEFAULT_SYSTEM_EXIT_TIMEOUT_IN_SECONDS );
@@ -181,14 +182,14 @@ public final class ForkedBooter
         }
     }
 
-    private PingScheduler listenToShutdownCommands( Long pluginPid )
+    private PingScheduler listenToShutdownCommands( Long ppid )
     {
         commandReader.addShutdownListener( createExitHandler() );
         AtomicBoolean pingDone = new AtomicBoolean( true );
         commandReader.addNoopListener( createPingHandler( pingDone ) );
 
         PingScheduler pingMechanisms = new PingScheduler( createPingScheduler(),
-                                                          pluginPid == null ? null : new PpidChecker( pluginPid ) );
+                                                          ppid == null ? null : new PpidChecker( ppid ) );
         if ( pingMechanisms.pluginProcessChecker != null )
         {
             Runnable checkerJob = processCheckerJob( pingMechanisms );
@@ -213,14 +214,16 @@ public final class ForkedBooter
                                  && !pingMechanism.pluginProcessChecker.isProcessAlive()
                                  && !pingMechanism.pingScheduler.isShutdown() )
                     {
-                        DumpErrorSingleton.getSingleton().dumpText( "Killing self fork JVM. Maven process died." );
+                        DumpErrorSingleton.getSingleton()
+                                .dumpText( "Killing self fork JVM. Maven process died." );
+
                         kill();
                     }
                 }
-                catch ( Exception e )
+                catch ( RuntimeException e )
                 {
                     DumpErrorSingleton.getSingleton()
-                            .dumpText( "System.exit() or native command error interrupted process checker." );
+                            .dumpException( e, "System.exit() or native command error interrupted process checker." );
                 }
             }
         };
@@ -276,7 +279,9 @@ public final class ForkedBooter
                     boolean hasPing = pingDone.getAndSet( false );
                     if ( !hasPing )
                     {
-                        DumpErrorSingleton.getSingleton().dumpText( "Killing self fork JVM. PING timeout elapsed." );
+                        DumpErrorSingleton.getSingleton()
+                                .dumpText( "Killing self fork JVM. PING timeout elapsed." );
+
                         kill();
                     }
                 }
